import unittest
import os
import numpy as np
import time
from zetane import OnnxViz
from zetane import context as ztn
from test.utils import get_data_file

class TestOnnx(unittest.TestCase):
    def setUp(self):
        self.viz = OnnxViz()
        self.engine = ztn.Context()

    #@unittest.skip("")
    def test_add(self):
        addition_file = get_data_file('addition.onnx')

        a = np.array([[1,1,1],[1,1,1]], dtype='int64')
        b = np.array([[1,1,1],[1,1,1]], dtype='int64')

        self.viz.create_onnx_model(addition_file)
        self.viz.model_inference({'0': a, '1': b})

        data = self.engine.form('graph.nodes.node.outputs.output.tensor.data').update()
        shape = self.engine.form('graph.nodes.node.outputs.output.tensor.shape').update()
        self.assertTrue(data.has_received())
        self.assertTrue(shape.has_received())

        data_vals = data.get_values()
        shape_vals = shape.get_values()

        expected_data = [2.0, 2.0, 2.0, 2.0, 2.0, 2.0]
        expected_shape = [2.0, 3.0]
        self.assertEqual(data_vals, expected_data)
        self.assertEqual(shape_vals, expected_shape)

    #@unittest.skip("")
    def test_arauco(self):
        arauco_onnx_file = get_data_file('arauco/arauco.onnx')
        input_file = np.load(
            get_data_file('arauco/sample.npy'))
        dense_28_relu = np.load(
            get_data_file('arauco/dense_28_relu_0.npy'))
        output = [-0.53007]
        shape = [1.0,1.0]

        self.viz.create_onnx_model(arauco_onnx_file)
        self.viz.model_inference({'dense_24_input': input_file})

        output_data = self.engine.form('graph.nodes.node=Add.outputs.output=dense_29.tensor.data').update()
        output_shape = self.engine.form('graph.nodes.node=Add.outputs.output=dense_29.tensor.shape').update()
        self.assertTrue(output_data.has_received())
        self.assertTrue(output_shape.has_received())

        vals = map(lambda n: round(n, 5), output_data.get_values())
        self.assertEqual(output, list(vals))

        shape_vals = output_shape.get_values()
        self.assertEqual(shape, shape_vals)

    #@unittest.skip("")
    def test_mosaic(self):
        mosaic_onnx_file = get_data_file('mosaic.onnx')

        self.viz.create_onnx_model(mosaic_onnx_file)
        i = 0
        while (i < 4):
            random_input = np.random.randn(1, 3, 224, 224)
            self.viz.model_inference({'input1': random_input}, sleep=3)
            i += 1

    #@unittest.skip("")
    def test_mosaic_bad_input(self):
        mosaic_onnx_file = get_data_file('mosaic.onnx')

        self.viz.create_onnx_model(mosaic_onnx_file)
        random_input = np.random.randn(1, 3, 224, 223)
        self.viz.model_inference({'input1': random_input})


    def test_mosaic_loop(self):
        mosaic_onnx_file = get_data_file('mosaic.onnx')
        self.viz.create_onnx_model(mosaic_onnx_file)

        i = 0
        while (i < 100):
            random_input = np.random.randn(1, 3, 224, 223)
            self.viz.model_inference({'input1': random_input})
            time.sleep(1.0)
            i += 1

    @unittest.skip("long test, enable manually")
    def test_all_cv(self):
        print('placeholder')
