import sys
import os
import math
import time
import string
import random
import numpy as np
from statistics import *
from numpy.random import randn
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
from zetane import context as ztn
from zetane import utils

# Launch zetane session
zcontext = ztn.Context()
zcontext.launch()
target_updates_per_second = 10
framecount = 0

#Create Panel
zPanel = zcontext.panel('panel_example', 0.5, 0.5, 0.05, 0.02)
zPanel.update()


# Create Line chart
zLineChart = zcontext.chart('Line chart', domain=[0.0, 10.0], range=[0.0, 10.0], visual_type='Line')
line_metric_1 = zLineChart.metric(label = 'Line Metric 1')
line_metric_2 = zLineChart.metric(label = 'Line Metric 2')
line_metric_3 = zLineChart.metric(label = 'Line Metric 3')

#Create Pie chart
zPieChart = zcontext.chart('Pie chart', domain=[0.0, 0.0], range=[0.0, 0.0], visual_type='Pie')
pie_metric_1 = zPieChart.metric(label = 'Pie Metric A')
pie_metric_2 = zPieChart.metric(label = 'Pie Metric B')
pie_metric_3 = zPieChart.metric(label = 'Pie Metric C')

# Create Surface chart
zSurfaceChart = zcontext.chart('Surface chart', domain=[0.0, 0.0], range=[0.0, 10.0], visual_type='Surface')
surface_metric_1 = zSurfaceChart.metric(label = 'Surface Metric 1')
zSurfaceChart.set_attribute(['wireframe'])


# Create Bar chart
zBarChart = zcontext.chart('Bar chart', domain=[0.0, 0.0], range=[0.0, 10.0], visual_type='Bar')
bar_metric_1 = zBarChart.metric(label = 'Bar Metric 1')
bar_metric_2 = zBarChart.metric(label = 'Bar Metric 2')
bar_metric_3 = zBarChart.metric(label = 'Bar Metric 3')


#Create Dial chart
zDialChart = zcontext.chart('Dial', domain=[0.0, 0.0], range=[0.0, 10.0], visual_type='Dial')
dial_metric_1 = zDialChart.metric(label = 'Dial Metric 1')

#Add to panel
zPanel.add_zobj(zLineChart)
zPanel.add_zobj(zPieChart)
zPanel.add_zobj(zSurfaceChart)
zPanel.add_zobj(zBarChart)
zPanel.add_zobj(zDialChart)

# Both of these work the same way
# zLineChart.send_to(zPanel)
# zPieChart.send_to(zPanel)
# zSurfaceChart.send_to(zPanel)
# zBarChart.send_to(zPanel)
# zDialChart.send_to(zPanel)

#Placement
utils.grid_placement([zLineChart, zPieChart, zDialChart, zSurfaceChart, zBarChart], max_number_of_columns=3, flip_y_order=False, padding=25.0, origin=(-25.0, 10.0, -45.0))

#Surface chart data
#surface_data = np.load("test/data/arr_3d.npy")
#surface_metric_1.set_3Dpoints(surface_data)
#zSurfaceChart.update()

# Main loop
while framecount < 1000000:
  data_points_1 = [x * 1.2 for x in randn(10).tolist()]
  data_points_2 = [x * 3.2 for x in randn(10).tolist()]
  data_points_3 = [x * 3.2 for x in randn(10).tolist()]


  #Line chart data
  line_metric_1.set_values(y=data_points_1)
  line_metric_2.set_values(y=data_points_2)
  line_metric_3.set_values(y=data_points_3)
  zLineChart.update()

  #Pie chart data
  pie_metric_1.append_values(y = data_points_1)
  pie_metric_2.append_values(y = data_points_2)
  pie_metric_3.append_values(y = data_points_3)
  zPieChart.update()

  #Bar chart data
  bar_metric_1.append_values(y = data_points_1)
  bar_metric_2.append_values(y = data_points_2)
  bar_metric_3.append_values(y = data_points_3)
  zBarChart.update()

  #Dial chart data
  dial_metric_1.append_values(y = data_points_1)
  zDialChart.update()

  time.sleep(1.0 / target_updates_per_second)
  framecount += 1

# Exit
print("Zetane session ended. Goodbye!")
